@@ -2,11 +2,11 @@ pub use self::file::File;
 pub use self::pathtype::PathType;
 pub use self::treegenerator::TreeGenerator;
 pub use self::dirtree::DirTree;
-pub use self::envmanager::EnvManager;
-pub mod checkenv;
+pub use self::configmanager::EnvManager;
+pub mod checkconfig;
 pub mod file;
 pub mod pathtype;
 pub mod treegenerator;
 pub mod dirtree;
 pub mod colormanager;
-pub mod envmanager;
\ No newline at end of file
+pub mod configmanager;
\ No newline at end of file
